pub struct HttpRoute {
pub path_prefix: String,
pub methods: Vec<i32>,
pub options: Option<RouteOptions>,
pub subdomain: String,
pub middleware: Vec<String>,
pub metrics: bool,
pub response_type: i32,
}Fields
path_prefix: Stringmethods: Vec<i32>HTTP methods for this route
options: Option<RouteOptions>subdomain: String“none” (default, bare domain), “any”, “exact:x”, “prefix:x-”, “suffix:.x”
middleware: Vec<String>Middleware names to apply (resolved from gateway config)
metrics: boolIf true, this route is a metrics endpoint (registered for Prometheus discovery, not public routing)
response_type: i32Error response format for this route (default: JSON)
Implementations
Sourceimpl HttpRoute
impl HttpRoute
Sourcepub fn methods(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<HttpMethod>>
pub fn methods( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<HttpMethod>>
Returns an iterator which yields the valid enum values contained in methods.
Sourcepub fn push_methods(&mut self, value: HttpMethod)
pub fn push_methods(&mut self, value: HttpMethod)
Appends the provided enum value to methods.
Sourcepub fn response_type(&self) -> ResponseType
pub fn response_type(&self) -> ResponseType
Returns the enum value of response_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_response_type(&mut self, value: ResponseType)
pub fn set_response_type(&mut self, value: ResponseType)
Sets response_type to the provided enum value.